V4L/DVB (12942): SAA7164: HVR2250 changes related to attach time tuner configuration

Previous message: [thread] [date] [author]
Next message: [thread] [date] [author]
From: Linux Kernel Mailing List
Date: Monday, September 21, 2009 - 10:01 am

Gitweb:     http://git.kernel.org/linus/90e801acb2134d905d98152a919128b9f56bbd33
Commit:     90e801acb2134d905d98152a919128b9f56bbd33
Parent:     c64b2f78b7912bad38a73bf892fb6d0da4673c67
Author:     Steven Toth <stoth@kernellabs.com>
AuthorDate: Thu Aug 27 18:08:21 2009 -0300
Committer:  Mauro Carvalho Chehab <mchehab@redhat.com>
CommitDate: Sat Sep 19 00:15:11 2009 -0300

    V4L/DVB (12942): SAA7164: HVR2250 changes related to attach time tuner configuration
    
    Ensure that by default all tuners are set correctly to master/slave mode.
    For all HVR2250's, ensure slave based tuners are caliberated during attach
    to avoid locking problems on tuner# above channel 91.
    
    HVR2200 tuner attach time to be reviewed in a future patch.
    
    Signed-off-by: Steven Toth <stoth@kernellabs.com>
    Signed-off-by: Mauro Carvalho Chehab <mchehab@redhat.com>
---
 drivers/media/video/saa7164/saa7164-dvb.c |   24 ++++++++++++++++++++----
 1 files changed, 20 insertions(+), 4 deletions(-)

diff --git a/drivers/media/video/saa7164/saa7164-dvb.c b/drivers/media/video/saa7164/saa7164-dvb.c
index 258eab5..238efc9 100644
--- a/drivers/media/video/saa7164/saa7164-dvb.c
+++ b/drivers/media/video/saa7164/saa7164-dvb.c
@@ -61,6 +61,14 @@ static struct tda18271_std_map hauppauge_tda18271_std_map = {
 static struct tda18271_config hauppauge_hvr22x0_tuner_config = {
 	.std_map	= &hauppauge_tda18271_std_map,
 	.gate		= TDA18271_GATE_ANALOG,
+	.role		= TDA18271_MASTER,
+};
+
+static struct tda18271_config hauppauge_hvr22x0s_tuner_config = {
+	.std_map	= &hauppauge_tda18271_std_map,
+	.gate		= TDA18271_GATE_ANALOG,
+	.role		= TDA18271_SLAVE,
+	.rf_cal_on_startup = 1
 };
 
 static struct s5h1411_config hauppauge_s5h1411_config = {
@@ -554,10 +562,18 @@ int saa7164_dvb_register(struct saa7164_tsport *port)
 			&i2c_bus->i2c_adap);
 
 		if (port->dvb.frontend != NULL) {
-			/* TODO: addr is in the card struct */
-			dvb_attach(tda18271_attach, port->dvb.frontend,
-				0xc0 >> 1, &i2c_bus->i2c_adap,
-				&hauppauge_hvr22x0_tuner_config);
+			if (port->nr == 0) {
+				/* Master TDA18271 */
+				/* TODO: addr is in the card struct */
+				dvb_attach(tda18271_attach, port->dvb.frontend,
+					0xc0 >> 1, &i2c_bus->i2c_adap,
+					&hauppauge_hvr22x0_tuner_config);
+			} else {
+				/* Slave TDA18271 */
+				dvb_attach(tda18271_attach, port->dvb.frontend,
+					0xc0 >> 1, &i2c_bus->i2c_adap,
+					&hauppauge_hvr22x0s_tuner_config);
+			}
 		}
 
 		break;
--
To unsubscribe from this list: send the line "unsubscribe git-commits-head" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Previous message: [thread] [date] [author]
Next message: [thread] [date] [author]

Messages in current thread:
V4L/DVB (12942): SAA7164: HVR2250 changes related to attac ..., Linux Kernel Mailing ..., (Mon Sep 21, 10:01 am)